@@ -1,6 +1,6 @@
-﻿/**
- * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+/**
+ * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 CKEDITOR.editorConfig = function( config ) {
@@ -17,6 +17,7 @@ CKEDITOR.editorConfig = function( config ) {
 		'clipboard,' +
 		'colorbutton,' +
 		'colordialog,' +
+		'copyformatting,' +
 		'contextmenu,' +
 		'dialogadvtab,' +
 		'div,' +
@@ -45,6 +46,7 @@ CKEDITOR.editorConfig = function( config ) {
 		'maximize,' +
 		'newpage,' +
 		'pagebreak,' +
+		'pastefromgdocs,' +
 		'pastefromword,' +
 		'pastetext,' +
 		'preview,' +
@@ -61,10 +63,12 @@ CKEDITOR.editorConfig = function( config ) {
 		'stylescombo,' +
 		'tab,' +
 		'table,' +
+		'tableselection,' +
 		'tabletools,' +
 		'templates,' +
 		'toolbar,' +
 		'undo,' +
+		'uploadimage,' +
 		'wysiwygarea';
 	// %REMOVE_END%
 };
