@@ -1,6 +1,6 @@
 ﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'colorbutton', 'de', {
 	auto: 'Automatisch',
@@ -45,7 +45,29 @@ CKEDITOR.plugins.setLang( 'colorbutton', 'de', {
 		F0FFFF: 'Azurblau',
 		F0F8FF: 'Alice Blau',
 		E6E6FA: 'Lavendel',
-		FFF: 'Weiß'
+		FFF: 'Weiß',
+		'1ABC9C': 'kräftiges Cyan',
+		'2ECC71': 'Smaragdgrün',
+		'3498DB': 'helles Blau',
+		'9B59B6': 'Amethystblau',
+		'4E5F70': 'Graublau',
+		'F1C40F': 'lebhaftes Gelb',
+		'16A085': 'Dunkelcyan',
+		'27AE60': 'Dunkelsmaragdgrün',
+		'2980B9': 'kräftiges Blau',
+		'8E44AD': 'Dunkelviolett',
+		'2C3E50': 'Entsättigtes blau',
+		'F39C12': 'Orange',
+		'E67E22': 'Möhrenfarben',
+		'E74C3C': 'Blassrot',
+		'ECF0F1': 'Glänzendes Silber',
+		'95A5A6': 'Helles Graublau',
+		'DDD': 'Hellgrau',
+		'D35400': 'Kürbisfarben',
+		'C0392B': 'kräftiges Rot',
+		'BDC3C7': 'Silber',
+		'7F8C8D': 'Graucyan',
+		'999': 'Dunkelgrau'
 	},
 	more: 'Weitere Farben...',
 	panelTitle: 'Farben',
