@@ -1,10 +1,10 @@
-﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+/*
+Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'docprops', 'nb', {
 	bgColor: 'Bakgrunnsfarge',
-	bgFixed: 'Lås bakgrunnsbilde',
+	bgFixed: 'Lås bakgrunnsbilde når man scroller (fixed)',
 	bgImage: 'URL for bakgrunnsbilde',
 	charset: 'Tegnsett',
 	charsetASCII: 'ASCII',
@@ -21,19 +21,19 @@ CKEDITOR.plugins.setLang( 'docprops', 'nb', {
 	chooseColor: 'Velg',
 	design: 'Design',
 	docTitle: 'Sidetittel',
-	docType: 'Dokumenttype header',
-	docTypeOther: 'Annet dokumenttype header',
+	docType: 'Header for dokumenttype',
+	docTypeOther: 'Annen header for dokumenttype',
 	label: 'Dokumentegenskaper',
 	margin: 'Sidemargin',
 	marginBottom: 'Bunn',
 	marginLeft: 'Venstre',
 	marginRight: 'Høyre',
 	marginTop: 'Topp',
-	meta: 'Meta-data',
+	meta: 'Metadata',
 	metaAuthor: 'Forfatter',
-	metaCopyright: 'Kopirett',
+	metaCopyright: 'Opphavsrett',
 	metaDescription: 'Dokumentbeskrivelse',
-	metaKeywords: 'Dokument nøkkelord (kommaseparert)',
+	metaKeywords: 'Dokumentnøkkelord (kommaseparert)',
 	other: '<annen>',
 	previewHtml: '<p>Dette er en <strong>eksempeltekst</strong>. Du bruker <a href="javascript:void(0)">CKEditor</a>.</p>',
 	title: 'Dokumentegenskaper',
