@@ -1,10 +1,10 @@
-﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+/*
+Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'format', 'hu', {
 	label: 'Formátum',
-	panelTitle: 'Formátum',
+	panelTitle: 'Bekezdés formátum',
 	tag_address: 'Címsor',
 	tag_div: 'Bekezdés (DIV)',
 	tag_h1: 'Fejléc 1',
